@@ -78,7 +78,8 @@ step_logit_new <-
 
 #' @export
 prep.step_logit <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   step_logit_new(
