@@ -126,7 +126,8 @@ step_nnmf_new <-
 
 #' @export
 prep.step_nnmf <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   if (x$num_comp > 0) {
