@@ -135,7 +135,8 @@ get_ord_lvls_num <- function(x, foo)
 
 #' @export
 prep.step_num2factor <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   res <- lapply(training[, col_names], get_ord_lvls_num, foo = x$transform)
