@@ -94,7 +94,7 @@ step_unknown_new <-
 
 #' @export
 prep.step_unknown <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   col_check <- dplyr::filter(info, variable %in% col_names)
   if (any(col_check$type != "nominal"))
     rlang::abort(
